| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Network.AWS.CloudTrail.StopLogging
Description
Suspends the recording of AWS API calls and log file delivery for the specified trail. Under most circumstances, there is no need to use this action. You can update a trail without stopping it first. This action is the only way to stop recording.
http://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_StopLogging.html
- data StopLogging
- stopLogging :: Text -> StopLogging
- slName :: Lens' StopLogging Text
- data StopLoggingResponse
- stopLoggingResponse :: StopLoggingResponse
Request
data StopLogging Source
Instances
| Eq StopLogging | |
| Ord StopLogging | |
| Read StopLogging | |
| Show StopLogging | |
| IsString StopLogging | |
| Monoid StopLogging | |
| AWSRequest StopLogging | |
| ToQuery StopLogging | |
| ToPath StopLogging | |
| ToHeaders StopLogging | |
| ToJSON StopLogging | |
| type Sv StopLogging = CloudTrail | |
| type Rs StopLogging = StopLoggingResponse |
Request constructor
Arguments
| :: Text | |
| -> StopLogging |
Request lenses
slName :: Lens' StopLogging Text Source
Communicates to CloudTrail the name of the trail for which to stop logging AWS API calls.
Response
Response constructor
stopLoggingResponse :: StopLoggingResponse Source
StopLoggingResponse constructor.